@@ -549,17 +549,6 @@ gensio_acc_get_frdata(struct gensio_accepter *acc)
     return acc->frdata;
 }
 
-static int
-strisallzero(const char *str)
-{
-    if (*str == '\0')
-	return 0;
-
-    while (*str == '0')
-	str++;
-    return *str == '\0';
-}
-
 void
 gensio_set_callback(struct gensio *io, gensio_event cb, void *user_data)
 {
@@ -1588,10 +1577,7 @@ str_to_gensio_accepter(const char *str,
 		       gensio_accepter_event cb, void *user_data,
 		       struct gensio_accepter **accepter)
 {
-    int err;
-    struct gensio_addr *ai = NULL;
-    int protocol = 0;
-    const char **args = NULL;
+    int err = GE_INVAL;
     struct registered_gensio_accepter *r;
     size_t len;
     bool retried = false;
@@ -1604,6 +1590,8 @@ str_to_gensio_accepter(const char *str,
 	str++;
  retry:
     for (r = reg_gensio_accs; r; r = r->next) {
+	const char **args = NULL;
+
 	len = strlen(r->name);
 	if (strncmp(r->name, str, len) != 0 ||
 			(str[len] != ',' && str[len] != '(' && str[len]))
@@ -1625,36 +1613,6 @@ str_to_gensio_accepter(const char *str,
 	goto retry;
     }
 
-    if (strisallzero(str)) {
-	err = gensio_terminal_acc_alloc("stdio", NULL, NULL, o, cb, user_data,
-					accepter);
-    } else {
-	err = gensio_scan_network_port(o, str, true, &ai, &protocol,
-				       NULL, NULL, &args);
-	if (err) {
-	    GENSIO_DECLARE_PPACCEPTER(p, o, cb, "base", user_data);
-	    gensio_pparm_log(&p, "Unknown gensio type: %s", str);
-	} else {
-	    if (protocol == GENSIO_NET_PROTOCOL_UDP) {
-		err = gensio_terminal_acc_alloc("udp", ai, args, o, cb,
-						user_data, accepter);
-	    } else if (protocol == GENSIO_NET_PROTOCOL_TCP) {
-		err = gensio_terminal_acc_alloc("tcp", ai, args, o, cb,
-						user_data, accepter);
-	    } else if (protocol == GENSIO_NET_PROTOCOL_SCTP) {
-		err = gensio_terminal_acc_alloc("sctp", ai, args, o, cb,
-						user_data, accepter);
-	    } else {
-		err = GE_INVAL;
-	    }
-
-	    gensio_addr_free(ai);
-	}
-    }
-
-    if (args)
-	gensio_argv_free(o, args);
-
     return err;
 }
 
@@ -1817,26 +1775,13 @@ register_gensio(struct gensio_os_funcs *o,
     return register_base_gensio(o, name, handler, alloc, NULL);
 }
 
-static bool
-is_serialdev_default_gensio(const char *str)
-{
-#if _WIN32
-    return strncmp(str, "COM", 3) == 0;
-#else
-    return *str == '/';
-#endif
-}
-
 int
 str_to_gensio(const char *str,
 	      struct gensio_os_funcs *o,
 	      gensio_event cb, void *user_data,
 	      struct gensio **gensio)
 {
-    int err = 0;
-    struct gensio_addr *ai = NULL;
-    bool is_port_set;
-    int protocol = 0;
+    int err = GE_INVAL;
     const char **args = NULL;
     struct registered_gensio *r;
     size_t len;
@@ -1862,49 +1807,17 @@ str_to_gensio(const char *str,
 		str++;
 	    err = r->handler(str, args, o, cb, user_data, gensio);
 	}
-	if (args)
-	    gensio_argv_free(o, args);
-	return err;
+	goto out;
     }
     if (!retried && gensio_loadlib(o, str)) {
 	retried = true;
 	goto retry;
     }
 
-    if (is_serialdev_default_gensio(str)) {
-	char *nstr = gensio_alloc_sprintf(o, "serialdev,%s", str);
-
-	if (!nstr)
-	    return GE_NOMEM;
-	
-	err = str_to_gensio(nstr, o, cb, user_data, gensio);
-	o->free(o, nstr);
-	goto out;
-    }
-
-    err = gensio_scan_network_port(o, str, false, &ai, &protocol,
-				   &is_port_set, NULL, &args);
-    if (err) {
+    do {
 	GENSIO_DECLARE_PPGENSIO(p, o, cb, "base", user_data);
 	gensio_pparm_log(&p, "Unknown gensio type: %s", str);
-    } else {
-	if (!is_port_set) {
-	    err = GE_INVAL;
-	} else if (protocol == GENSIO_NET_PROTOCOL_UDP) {
-	    err = gensio_terminal_alloc("udp", ai, args, o, cb, user_data,
-					gensio);
-	} else if (protocol == GENSIO_NET_PROTOCOL_TCP) {
-	    err = gensio_terminal_alloc("tcp", ai, args, o, cb, user_data,
-					gensio);
-	} else if (protocol == GENSIO_NET_PROTOCOL_SCTP) {
-	    err = gensio_terminal_alloc("sctp", ai, args, o, cb, user_data,
-					gensio);
-	} else {
-	    err = GE_INVAL;
-	}
-
-	gensio_addr_free(ai);
-    }
+    } while(false);
 
  out:
     if (args)
@@ -3920,6 +3833,16 @@ gensio_time_to_usecs(gensio_time *t1)
     return v;
 }
 
+int64_t
+gensio_time_to_nsecs(gensio_time *t1)
+{
+    int64_t v;
+
+    v = t1->secs * GENSIO_NSECS_IN_SEC;
+    v += GENSIO_NSECS_TO_USECS(t1->nsecs);
+    return v;
+}
+
 void
 gensio_msecs_to_time(gensio_time *t1, int64_t v)
 {
@@ -3934,6 +3857,13 @@ gensio_usecs_to_time(gensio_time *t1, int64_t v)
     t1->nsecs = GENSIO_USECS_TO_NSECS(v % 1000000);
 }
 
+void
+gensio_nsecs_to_time(gensio_time *t1, int64_t v)
+{
+    t1->secs = v / GENSIO_NSECS_IN_SEC;
+    t1->nsecs = v % GENSIO_NSECS_IN_SEC;
+}
+
 int64_t
 gensio_time_diff_nsecs(gensio_time *t1, gensio_time *t2)
 {
@@ -4064,5 +3994,38 @@ gensio_str_to_onoff(const char *sval)
     return -1;
 }
 
+const char *
+gensio_flush_to_str(unsigned int ival)
+{
+    switch(ival) {
+    case 0:
+	return "0";
+
+    case GENSIO_SER_FLUSH_RECV:
+	return "recv";
+
+    case GENSIO_SER_FLUSH_XMIT:
+	return "xmit";
+
+    case GENSIO_SER_FLUSH_BOTH:
+	return "both";
+
+    default:
+	return "?";
+    }
+}
+
+int
+gensio_str_to_flush(const char *sval)
+{
+    if (strcmp(sval, "recv") == 0)
+	return GENSIO_SER_FLUSH_RECV;
+    if (strcmp(sval, "xmit") == 0)
+	return GENSIO_SER_FLUSH_XMIT;
+    if (strcmp(sval, "both") == 0)
+	return GENSIO_SER_FLUSH_BOTH;
+    return -1;
+}
+
 /* For lack of a better place to put this. */
 bool gensio_uucp_locking_enabled = true;
