@@ -153,14 +153,16 @@ static int
 kiss_ul_write(struct gensio_filter *filter,
 	      gensio_ul_filter_data_handler handler, void *cb_data,
 	      gensiods *rcount,
-	      const struct gensio_sg *sg, gensiods sglen,
+	      const struct gensio_sg *isg, gensiods sglen,
 	      const char *const *auxdata)
 {
     struct kiss_filter *kfilter = filter_to_kiss(filter);
-    unsigned int i, tnc = 0;
+    unsigned int tnc = 0;
     int rv = 0;
 
     if (auxdata) {
+	unsigned int i;
+
 	for (i = 0; auxdata[i]; i++) {
 	    if (strncmp(auxdata[i], "tnc:", 4) == 0) {
 		char *end;
@@ -199,8 +201,8 @@ kiss_ul_write(struct gensio_filter *filter,
 	kfilter->write_data[kfilter->write_data_len++] = 0xc0;
 	kiss_add_wrbyte(kfilter, tnc << 4);
 	for (i = 0; i < sglen; i++) {
-	    gensiods inlen = sg[i].buflen;
-	    const unsigned char *buf = sg[i].buf;
+	    gensiods inlen = isg[i].buflen;
+	    const unsigned char *buf = isg[i].buf;
 
 	    for (j = 0; j < inlen; j++) {
 		if (kfilter->user_write_pos >= kfilter->max_write_size)
@@ -253,7 +255,7 @@ kiss_ll_write(struct gensio_filter *filter,
 		gensio_ll_filter_data_handler handler, void *cb_data,
 		gensiods *rcount,
 		unsigned char *buf, gensiods buflen,
-		const char *const *auxdata)
+		const char *const *iauxdata)
 {
     struct kiss_filter *kfilter = filter_to_kiss(filter);
     gensiods in_buflen = buflen, count = 0;
@@ -480,7 +482,8 @@ handle_get_ranges(bool vals[16], const char *str)
 }
 
 int
-gensio_kiss_filter_alloc(struct gensio_os_funcs *o, const char * const args[],
+gensio_kiss_filter_alloc(struct gensio_pparm_info *p,
+			 struct gensio_os_funcs *o, const char * const args[],
 			 bool server, struct gensio_filter **rfilter)
 {
     struct kiss_filter *kfilter;
@@ -499,60 +502,67 @@ gensio_kiss_filter_alloc(struct gensio_os_funcs *o, const char * const args[],
     int rv;
 
     for (i = 0; args && args[i]; i++) {
-	if (gensio_check_keyds(args[i], "readbuf", &max_read_size) > 0)
+	if (gensio_pparm_ds(p, args[i], "readbuf", &max_read_size) > 0)
 	    continue;
-	if (gensio_check_keyds(args[i], "writebuf", &max_write_size) > 0)
+	if (gensio_pparm_ds(p, args[i], "writebuf", &max_write_size) > 0)
 	    continue;
-	if (gensio_check_keyvalue(args[i], "tncs", &str) > 0) {
+	if (gensio_pparm_value(p, args[i], "tncs", &str) > 0) {
 	    rv = handle_get_ranges(tncs, str);
 	    if (rv)
 		return rv;
 	    continue;
 	}
-	if (gensio_check_keyuint(args[i], "txdelay", &txdelay) > 0) {
+	if (gensio_pparm_uint(p, args[i], "txdelay", &txdelay) > 0) {
 	    if (txdelay > 2550)
 		return GE_INVAL;
 	    continue;
 	}
-	if (gensio_check_keyuint(args[i], "persist", &persist) > 0) {
+	if (gensio_pparm_uint(p, args[i], "persist", &persist) > 0) {
 	    if (persist > 255)
 		return GE_INVAL;
 	    continue;
 	}
-	if (gensio_check_keyuint(args[i], "slottime", &slot_time) > 0) {
+	if (gensio_pparm_uint(p, args[i], "slottime", &slot_time) > 0) {
 	    if (slot_time > 2550)
 		return GE_INVAL;
 	    continue;
 	}
-	if (gensio_check_keybool(args[i], "fullduplex", &full_duplex) > 0)
+	if (gensio_pparm_bool(p, args[i], "fullduplex", &full_duplex) > 0)
 	    continue;
-	if (gensio_check_keyuint(args[i], "sethardware", &set_hardware) > 0) {
+	if (gensio_pparm_uint(p, args[i], "sethardware", &set_hardware) > 0) {
 	    if (set_hardware > 255)
 		return GE_INVAL;
 	    set_hardware_set = true;
 	    continue;
 	}
-	if (gensio_check_keybool(args[i], "server", &server) > 0)
+	if (gensio_pparm_bool(p, args[i], "server", &server) > 0)
 	    continue;
-	if (gensio_check_keyvalue(args[i], "setupstr", &setupstr) > 0)
+	if (gensio_pparm_value(p, args[i], "setupstr", &setupstr) > 0)
 	    continue;
-	if (gensio_check_keyuint(args[i], "setup-delay", &setup_delay) > 0)
+	if (gensio_pparm_uint(p, args[i], "setup-delay", &setup_delay) > 0)
 	    continue;
-	if (gensio_check_keybool(args[i], "d710", &bval) > 0) {
+	if (gensio_pparm_bool(p, args[i], "d710", &bval) > 0) {
 	    if (bval)
 		setupstr = "xflow on\rhbaud 1200\rkiss on\rrestart\r";
 	    continue;
 	}
-	if (gensio_check_keybool(args[i], "d710-9600", &bval) > 0) {
+	if (gensio_pparm_bool(p, args[i], "d710-9600", &bval) > 0) {
 	    if (bval)
 		setupstr = "xflow on\rhbaud 9600\rkiss on\rrestart\r";
 	    continue;
 	}
+	gensio_pparm_unknown_parm(p, args[i]);
 	return GE_INVAL;
     }
 
-    if (max_read_size < 256 || max_write_size < 256)
+    if (max_read_size < 256) {
+	gensio_pparm_slog(p, "readbuf must be >= 256");
 	return GE_INVAL;
+    }
+    if (max_write_size < 256) {
+	gensio_pparm_slog(p, "writebuf must be >= 256");
+	return GE_INVAL;
+    }
 
     kfilter = o->zalloc(o, sizeof(*kfilter));
     if (!kfilter)
