@@ -429,6 +429,12 @@ sgensio_linestate(struct gensio *io, unsigned int linestate)
     sgensio_call(io, linestate, "linestate");
 }
 
+static void
+sgensio_linestate_mask(struct gensio *io, unsigned int linestate)
+{
+    sgensio_call(io, linestate, "linestate_mask");
+}
+
 static void
 sgensio_signature(struct gensio *io)
 {
@@ -665,8 +671,14 @@ gensio_child_event(struct gensio *io, void *user_data, int event, int readerr,
 
 	PyTuple_SET_ITEM(args, 2, gensio_py_handle_auxdata(auxdata));
 
-	rv = swig_finish_call_rv_int(data->handler_val, "new_channel",
-				     args, false);
+	/*
+	 * Do not return the return code from here, return 0.  If you
+	 * return non-zero from here, then gensio will delete the
+	 * gensio.  Python will then free the gensio if the user
+	 * didn't keep a copy both of which are bad situations.
+	 */
+	swig_finish_call_rv_int(data->handler_val, "new_channel",
+				args, false);
 	break;
 
     case GENSIO_EVENT_SEND_BREAK:
@@ -892,6 +904,10 @@ gensio_child_event(struct gensio *io, void *user_data, int event, int readerr,
 	sgensio_linestate(io, *((unsigned int *) buf));
 	break;
 
+    case GENSIO_EVENT_SER_LINESTATE_MASK:
+	sgensio_linestate_mask(io, *((unsigned int *) buf));
+	break;
+
     case GENSIO_EVENT_SER_SIGNATURE:
 	sgensio_signature(io);
 	break;
@@ -1106,6 +1122,12 @@ gensio_acc_child_event(struct gensio_accepter *accepter, void *user_data,
 	PyTuple_SET_ITEM(args, 0, acc_ref.val);
 	PyTuple_SET_ITEM(args, 1, io_ref.val);
 
+	/*
+	 * Do not return the return code from here, return 0.  If you
+	 * return non-zero from here, then gensio will delete the
+	 * gensio.  Python will then free the gensio if the user
+	 * didn't keep a copy both of which are bad situations.
+	 */
 	swig_finish_call(data->handler_val, "new_connection", args, false);
 
 	OI_PY_STATE_PUT(gstate);
