@@ -12,3 +12,5 @@ print("Test unix accepter connect")
 TestAcceptConnect(o, "unix,/tmp/gensiotest", "unix,/tmp/gensiotest2",
                   "unix,/tmp/gensiotest",
                   do_small_test, use_port = False)
+del o
+test_shutdown()
