@@ -2955,9 +2955,18 @@ static int
 acc_event(struct gensio_accepter *accepter, void *user_data,
 	  int event, void *data)
 {
-    struct gdata *ginfo = gensio_acc_get_user_data(accepter);
+    struct gdata *ginfo;
     struct gensio *io;
 
+    if (event == GENSIO_ACC_EVENT_PARMLOG) {
+	/* NOTE: accepter will be NULL in this case. */
+	struct gensio_parmlog_data *p = (struct gensio_parmlog_data *) data;
+	vlog_event(LOG_ERR, p->log, p->args);
+	return 0;
+    }
+
+    ginfo = gensio_acc_get_user_data(accepter);
+
     if (event == GENSIO_ACC_EVENT_LOG) {
 	struct gensio_loginfo *li = data;
 	int level = LOG_INFO;
@@ -3324,7 +3333,7 @@ main(int argc, char *argv[])
     }
 
     if (other_acc_str) {
-	s = gensio_alloc_sprintf(o, other_acc_str, iptype, port);
+	s = gensio_strdup(o, other_acc_str);
 	if (!s) {
 	    log_event(LOG_ERR, "Could not allocate '%s' descriptor\n",
 		      other_acc_str);
